@@ -1,9 +1,5 @@
 import random
 
-def hello_world(x):
-    result = "hello "+x
-    return result
-
 def ind_max(x):
     """
     returns the index that corresponds to the maximum value in array x
@@ -11,6 +7,12 @@ def ind_max(x):
     m = max(x)
     return x.index(m)
 
+def hello_world():
+    """
+    test function to see if package is installed in editable mode
+    """
+    print("hello universe")
+
 class EpsilonGreedy():
     """
 
@@ -37,7 +39,7 @@ class EpsilonGreedy():
         self.rewards    = rewards
         self.conv_rates = [0 for i in range(n_arms)] if conv_rates is None else conv_rates
         self.counts     = [0 for i in range(n_arms)] if counts is None else counts
-        self.values     = [i*j for i,j in zip(conv_rates,rewards)]
+        self.values     = [i*j for i,j in zip(self.conv_rates,self.rewards)]
         # raise error if n_arms does not equal number of entries in counts or values
         if ((n_arms != len(self.counts)) or (n_arms != len(self.values)) or (n_arms != len(self.conv_rates))):
             raise ValueError("n_arms does not match the length of counts/values/conv_rates")
@@ -60,15 +62,27 @@ class EpsilonGreedy():
         self.values[chosen_arm] = new_value
         return
     
-    def batch_update(self, chosen_arm, num_times_chosen, num_successes, new_rewards=None):
+    def batch_update(self, chosen_arm, num_times_chosen, num_successes, observed_reward=None):
+        
+        # save previous algo parameter values
+        prev_counts     = self.counts.copy()
+        prev_conv_rates = self.conv_rates.copy()
+        prev_rewards    = self.rewards.copy()
+        prev_values     = self.values.copy()
+
         # increments counts for chosen arm
-        self.counts[chosen_arm] = self.counts[chosen_arm] + num_times_chosen
-        # update rewards
-        self.rewards = self.rewards if new_rewards is None else new_rewards
+        self.counts[chosen_arm] = prev_counts[chosen_arm] + num_times_chosen
+
+        # update conversion rates
+        self.conv_rates[chosen_arm] = ((prev_conv_rates[chosen_arm] * prev_counts[chosen_arm]) + num_successes) / self.counts[chosen_arm]
+
         # calculate new average reward for chosen arm
-        n = self.counts[chosen_arm]
-        prev_value = self.values[chosen_arm]
-        new_value = ((n - num_times_chosen) / float(n)) * prev_value + (num_successes / float(n)) * self.rewards[chosen_arm]
-        self.values[chosen_arm] = new_value
+        observed_reward = prev_rewards[chosen_arm] if observed_reward is None else observed_reward
+        prev_total_rewards = (prev_rewards[chosen_arm] * prev_conv_rates[chosen_arm] * prev_counts[chosen_arm])
+        new_total_rewards  = num_successes * observed_reward
+        self.rewards[chosen_arm] = (prev_total_rewards + new_total_rewards) / self.counts[chosen_arm]
+        
+        # calculate new average value for chosen arm
+        self.values[chosen_arm] = (self.conv_rates[chosen_arm] * self.counts[chosen_arm] * self.rewards[chosen_arm])/self.counts[chosen_arm]
         return
 
