@@ -1,5 +1,5 @@
 from ._bernoulli import BernoulliArm
 
 __all__ = [
-    BernoulliArm
+    'BernoulliArm'
 ]
\ No newline at end of file
